function varargout = splash(varargin)
% SPLASH M-file for splash.fig
%      SPLASH, by itself, creates a new SPLASH or raises the existing
%      singleton*.
%
%      H = SPLASH returns the handle to a new SPLASH or the handle to
%      the existing singleton*.
%
%      SPLASH('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named SPLASH in SPLASH.M with the given input arguments.
%
%      SPLASH('Property','Value',...) creates a new SPLASH or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before splash_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to splash_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% Code construction assisted by GUIDE
%
%    GENERAL
%
%      Omitted.
%
%    INPUT/S
%
%      -
%          
%           
%    OUTPUT/S
%
%      -
%
%    PENDING WORK
%
%      -
%
%    KNOWN BUG/S
%
%      -
%
%    COMMENT/S
%
%      -
%
%    RELATED FUNCTION/S
%
%      
%
%    ABOUT
%
%      -Created:     February 12th, 2004
%      -Last update: 
%      -Revision:    0.0.9
%      -Author:      R. S. Schestowitz, University of Manchester
% ==============================================================

% Edit the above text to modify the response to help_button register

% Last Modified by GUIDE v2.5 18-Feb-2004 08:44:46

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
    'gui_Singleton',  gui_Singleton, ...
    'gui_OpeningFcn', @splash_OpeningFcn, ...
    'gui_OutputFcn',  @splash_OutputFcn, ...
    'gui_LayoutFcn',  [] , ...
    'gui_Callback',   []);
if nargin & isstr(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT

% --- Executes just before register is made visible.
function splash_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to register (see VARARGIN)

% Choose default command line output for register
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

if strcmp(get(hObject,'Visible'),'off')
    initialize_gui(hObject, handles);
end

% UIWAIT makes register pause for user response (see UIRESUME)
% uiwait(handles.Splash_window);


% --- Outputs from this function are returned to the command line.
function varargout = splash_OutputFcn(hObject, eventdata, handles)
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;



function initialize_gui(fig_handle, handles)

set(handles.caption, 'String', ['Victoria University of Manchester       Version ', [get_version]]); 
% Put some bigger logo here

axes(handles.aart_logo);
axis off;
aart_logo = imread('aartlrg.jpg');
imshow(aart_logo,[0,255]);

axes(handles.aart_title);
axis off;
aart_logo = imread('aarttitle.jpg');
imshow(aart_logo,[0,255]);

% destroy splash screen later in the function that calls this routine.